document.addEventListener('DOMContentLoaded', () => {
  const themeToggle = document.getElementById('themeToggle');
  const cryptoList = document.getElementById('cryptoList');
  const loadingIndicator = document.getElementById('loadingIndicator');
  const timeframeSelect = document.getElementById('timeframe');
  const sortBySelect = document.getElementById('sortBy');
  const searchInput = document.getElementById('cryptoSearch');

  // Theme toggling
  themeToggle.addEventListener('click', () => {
    document.body.dataset.theme = document.body.dataset.theme === 'dark' ? 'light' : 'dark';
  });

  // Format numbers
  const formatNumber = (num) => {
    return new Intl.NumberFormat('en-US', {
      style: 'currency',
      currency: 'USD',
      minimumFractionDigits: 2,
      maximumFractionDigits: 2
    }).format(num);
  };

  // Create crypto card
  const createCryptoCard = (crypto) => {
    const card = document.createElement('div');
    card.className = 'crypto-card';
    card.innerHTML = `
      <h3>${crypto.symbol}</h3>
      <p>Price: ${formatNumber(crypto.price)}</p>
      <p>24h Change: <span style="color: ${crypto.change24h >= 0 ? '#00b894' : '#d63031'}">${crypto.change24h}%</span></p>
      <p>Volume: ${formatNumber(crypto.volume)}</p>
    `;
    return card;
  };

  // Fetch data from TradingView
  const fetchCryptoData = async () => {
    try {
      loadingIndicator.style.display = 'block';
      cryptoList.innerHTML = '';

      // Using TradingView's screener data
      const response = await fetch('https://scanner.tradingview.com/crypto/scan', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({
          filter: [
            {
              left: "market_cap_basic",
              operation: "nempty"
            }
          ],
          options: {
            lang: "en"
          },
          markets: ["crypto"],
          symbols: {
            query: {
              types: []
            },
            tickers: []
          },
          columns: [
            "name",
            "close",
            "change",
            "volume",
            "market_cap_basic"
          ],
          sort: {
            sortBy: "market_cap_basic",
            sortOrder: "desc"
          }
        })
      });

      const data = await response.json();
      
      loadingIndicator.style.display = 'none';
      
      // Process and display data
      data.data.forEach(crypto => {
        const cryptoData = {
          symbol: crypto.s,
          price: crypto.d[1],
          change24h: crypto.d[2],
          volume: crypto.d[3],
          marketCap: crypto.d[4]
        };
        cryptoList.appendChild(createCryptoCard(cryptoData));
      });
    } catch (error) {
      console.error('Error fetching data:', error);
      loadingIndicator.textContent = 'Error loading data. Please try again later.';
    }
  };

  // Event listeners for controls
  timeframeSelect.addEventListener('change', fetchCryptoData);
  sortBySelect.addEventListener('change', fetchCryptoData);
  searchInput.addEventListener('input', (e) => {
    const searchTerm = e.target.value.toLowerCase();
    Array.from(cryptoList.children).forEach(card => {
      const symbol = card.querySelector('h3').textContent.toLowerCase();
      card.style.display = symbol.includes(searchTerm) ? 'block' : 'none';
    });
  });

  // Initial load
  fetchCryptoData();
});
